# Kivia

A python cli which solves all problems in cli

pip3 install kivia

#### Note : Your python3 version must be 3.7 or above to use this 
##### check it by typing python3 --version
## Usage


### Install to Bash
```
    kpm bindtobash    
```

### installing a module

``kpm install [modulename]``

### for more help type
``kpm --help``

